@@ -27,14 +27,46 @@ def _status_action(app, user, status_id, action):
 def create_app(domain, scheme='https'):
     url = '{}://{}/api/v1/apps'.format(scheme, domain)
 
-    data = {
+    json = {
         'client_name': CLIENT_NAME,
         'redirect_uris': 'urn:ietf:wg:oauth:2.0:oob',
         'scopes': SCOPES,
         'website': CLIENT_WEBSITE,
     }
 
-    return http.anon_post(url, data).json()
+    return http.anon_post(url, json=json).json()
+
+
+def register_account(app, username, email, password, locale="en", agreement=True):
+    """
+    Register an account
+    https://docs.joinmastodon.org/methods/accounts/#create
+    """
+    token = fetch_app_token(app)["access_token"]
+    url = f"{app.base_url}/api/v1/accounts"
+    headers = {"Authorization": f"Bearer {token}"}
+
+    json = {
+        "username": username,
+        "email": email,
+        "password": password,
+        "agreement": agreement,
+        "locale": locale
+    }
+
+    return http.anon_post(url, json=json, headers=headers).json()
+
+
+def fetch_app_token(app):
+    json = {
+        "client_id": app.client_id,
+        "client_secret": app.client_secret,
+        "grant_type": "client_credentials",
+        "redirect_uri": "urn:ietf:wg:oauth:2.0:oob",
+        "scope": "read write"
+    }
+
+    return http.anon_post(f"{app.base_url}/oauth/token", json=json).json()
 
 
 def login(app, username, password):
@@ -49,7 +81,7 @@ def login(app, username, password):
         'scope': SCOPES,
     }
 
-    response = http.anon_post(url, data, allow_redirects=False)
+    response = http.anon_post(url, data=data, allow_redirects=False)
 
     # If auth fails, it redirects to the login page
     if response.is_redirect:
@@ -79,7 +111,7 @@ def request_access_token(app, authorization_code):
         'redirect_uri': 'urn:ietf:wg:oauth:2.0:oob',
     }
 
-    return http.anon_post(url, data, allow_redirects=False).json()
+    return http.anon_post(url, data=data, allow_redirects=False).json()
 
 
 def post_status(
@@ -96,17 +128,17 @@ def post_status(
     content_type=None,
 ):
     """
-    Posts a new status.
-    https://github.com/tootsuite/documentation/blob/master/Using-the-API/API.md#posting-a-new-status
+    Publish a new status.
+    https://docs.joinmastodon.org/methods/statuses/#create
     """
 
     # Idempotency key assures the same status is not posted multiple times
     # if the request is retried.
     headers = {"Idempotency-Key": uuid.uuid4().hex}
 
-    params = {
+    json = {
         'status': status,
-        'media_ids[]': media_ids,
+        'media_ids': media_ids,
         'visibility': visibility,
         'sensitive': str_bool(sensitive),
         'spoiler_text': spoiler_text,
@@ -116,9 +148,17 @@ def post_status(
     }
 
     if content_type:
-        params['content_type'] = content_type
+        json['content_type'] = content_type
 
-    return http.post(app, user, '/api/v1/statuses', params, headers=headers).json()
+    return http.post(app, user, '/api/v1/statuses', json=json, headers=headers).json()
+
+
+def fetch_status(app, user, id):
+    """
+    Fetch a single status
+    https://docs.joinmastodon.org/methods/statuses/#get
+    """
+    return http.get(app, user, f"/api/v1/statuses/{id}").json()
 
 
 def delete_status(app, user, status_id):
@@ -238,21 +278,18 @@ def upload_media(app, user, file, description=None):
     ).json()
 
 
-def search(app, user, query, resolve):
-    return http.get(app, user, '/api/v2/search', {
-        'q': query,
-        'resolve': resolve,
+def search(app, user, query, resolve=False, type=None):
+    """
+    Perform a search.
+    https://docs.joinmastodon.org/methods/search/#v2
+    """
+    return http.get(app, user, "/api/v2/search", {
+        "q": query,
+        "resolve": resolve,
+        "type": type
     }).json()
 
 
-def search_accounts(app, user, query):
-    return http.get(app, user, '/api/v2/search', {
-        'q': query,
-        'type': 'accounts',
-        'resolve': True,
-    }).json()['accounts']
-
-
 def follow(app, user, account):
     return _account_action(app, user, account, 'follow')
 
@@ -260,6 +297,7 @@ def follow(app, user, account):
 def unfollow(app, user, account):
     return _account_action(app, user, account, 'unfollow')
 
+
 def _get_account_list(app, user, path):
     accounts = []
     while path:
@@ -268,10 +306,12 @@ def _get_account_list(app, user, path):
         path = _get_next_path(response.headers)
     return accounts
 
+
 def following(app, user, account):
     path = '/api/v1/accounts/{}/{}'.format(account, 'following')
     return _get_account_list(app, user, path)
 
+
 def followers(app, user, account):
     path = '/api/v1/accounts/{}/{}'.format(account, 'followers')
     return _get_account_list(app, user, path)
@@ -304,7 +344,7 @@ def single_status(app, user, status_id):
 
 
 def get_notifications(app, user, exclude_types=[], limit=20):
-    params={"exclude_types[]": exclude_types, "limit": limit}
+    params = {"exclude_types[]": exclude_types, "limit": limit}
     return http.get(app, user, '/api/v1/notifications', params).json()
 
 
