@@ -4,10 +4,10 @@ import sys
 
 from toot import api, config
 from toot.auth import login_interactive, login_browser_interactive, create_app_interactive
-from toot.exceptions import ConsoleError, NotFoundError
+from toot.exceptions import ApiError, ConsoleError
 from toot.output import (print_out, print_instance, print_account, print_acct_list,
                          print_search_results, print_timeline, print_notifications)
-from toot.utils import assert_domain_exists, editor_input, multiline_input, EOF_KEY
+from toot.utils import editor_input, multiline_input, EOF_KEY
 
 
 def get_timeline_generator(app, user, args):
@@ -255,14 +255,11 @@ def _find_account(app, user, account_name):
     if not account_name:
         raise ConsoleError("Empty account name given")
 
-    accounts = api.search_accounts(app, user, account_name)
+    normalized_name = account_name.lstrip("@").lower()
 
-    if account_name[0] == "@":
-        account_name = account_name[1:]
-
-    for account in accounts:
-        # Normalise string matching because usernames are case insensitive
-        if account['acct'].lower() == account_name.lower():
+    response = api.search(app, user, account_name, type="accounts", resolve=True)
+    for account in response["accounts"]:
+        if account["acct"].lower() == normalized_name:
             return account
 
     raise ConsoleError("Account not found")
@@ -279,11 +276,13 @@ def unfollow(app, user, args):
     api.unfollow(app, user, account['id'])
     print_out("<green>✓ You are no longer following {}</green>".format(args.account))
 
+
 def following(app, user, args):
     account = _find_account(app, user, args.account)
     response = api.following(app, user, account['id'])
     print_acct_list(response)
 
+
 def followers(app, user, args):
     account = _find_account(app, user, args.account)
     response = api.followers(app, user, account['id'])
@@ -329,12 +328,10 @@ def instance(app, user, args):
     if not name:
         raise ConsoleError("Please specify instance name.")
 
-    assert_domain_exists(name)
-
     try:
         instance = api.get_instance(name, args.scheme)
         print_instance(instance)
-    except NotFoundError:
+    except ApiError:
         raise ConsoleError(
             "Instance not found at {}.\n"
             "The given domain probably does not host a Mastodon instance.".format(name)
