@@ -3,13 +3,13 @@
 import os
 import re
 import sys
+import textwrap
 
-from datetime import datetime, timezone
 from textwrap import wrap
-from wcwidth import wcswidth
 from toot.tui.utils import parse_datetime
+from wcwidth import wcswidth
 
-from toot.utils import format_content, get_text, parse_html
+from toot.utils import get_text, parse_html
 from toot.wcstring import wc_wrap
 
 
@@ -88,17 +88,28 @@ def print_instance(instance):
     print_out("<green>{}</green>".format(instance['title']))
     print_out("<blue>{}</blue>".format(instance['uri']))
     print_out("running Mastodon {}".format(instance['version']))
-    print_out("")
+    print_out()
 
-    description = instance['description'].strip()
-    if not description:
-        return
+    description = instance.get("description")
+    if description:
+        for paragraph in re.split(r"[\r\n]+", description.strip()):
+            paragraph = get_text(paragraph)
+            print_out(textwrap.fill(paragraph, width=80))
+            print_out()
 
-    lines = [line.strip() for line in format_content(description) if line.strip()]
-    for line in lines:
-        for l in wrap(line.strip()):
-            print_out(l)
-        print_out()
+    rules = instance.get("rules")
+    if rules:
+        print_out("Rules:")
+        for ordinal, rule in enumerate(rules):
+            ordinal = f"{ordinal + 1}."
+            lines = textwrap.wrap(rule["text"], 80 - len(ordinal))
+            first = True
+            for line in lines:
+                if first:
+                    print_out(f"{ordinal} {line}")
+                    first = False
+                else:
+                    print_out(f"{' ' * len(ordinal)} {line}")
 
 
 def print_account(account):
@@ -127,6 +138,7 @@ HASHTAG_PATTERN = re.compile(r'(?<!\w)(#\w+)\b')
 def highlight_hashtags(line):
     return re.sub(HASHTAG_PATTERN, '<cyan>\\1</cyan>', line)
 
+
 def print_acct_list(accounts):
     for account in accounts:
         print_out("* <green>@{}</green> {}".format(
@@ -134,6 +146,7 @@ def print_acct_list(accounts):
             account['display_name']
         ))
 
+
 def print_search_results(results):
     accounts = results['accounts']
     hashtags = results['hashtags']
@@ -155,6 +168,7 @@ def print_status(status, width):
     content = reblog['content'] if reblog else status['content']
     media_attachments = reblog['media_attachments'] if reblog else status['media_attachments']
     in_reply_to = status['in_reply_to_id']
+    poll = reblog.get('poll') if reblog else status.get('poll')
 
     time = parse_datetime(status['created_at'])
     time = time.strftime('%Y-%m-%d %H:%M %Z')
@@ -186,6 +200,9 @@ def print_status(status, width):
             for line in wc_wrap(url, width):
                 print_out(line)
 
+    if poll:
+        print_poll(poll)
+
     print_out("\n{}{}{}".format(
         "ID <yellow>{}</yellow>  ".format(status['id']),
         "↲ In reply to <yellow>{}</yellow>  ".format(in_reply_to) if in_reply_to else "",
@@ -193,6 +210,31 @@ def print_status(status, width):
     ))
 
 
+def print_poll(poll):
+    print_out()
+    for idx, option in enumerate(poll["options"]):
+        perc = (round(100 * option["votes_count"] / poll["votes_count"])
+            if poll["votes_count"] else 0)
+
+        if poll["voted"] and poll["own_votes"] and idx in poll["own_votes"]:
+            voted_for = " <yellow>✓</yellow>"
+        else:
+            voted_for = ""
+
+        print_out(f'{option["title"]} - {perc}% {voted_for}')
+
+    poll_footer = f'Poll · {poll["votes_count"]} votes'
+
+    if poll["expired"]:
+        poll_footer += " · Closed"
+
+    if poll["expires_at"]:
+        expires_at = parse_datetime(poll["expires_at"]).strftime("%Y-%m-%d %H:%M")
+        poll_footer += f" · Closes on {expires_at}"
+
+    print_out("\n{}".format(poll_footer))
+
+
 def print_timeline(items, width=100):
     print_out("─" * width)
     for item in items:
